@@ -3,6 +3,7 @@
  * Copyright (C) 2007,2008 Jaap Haitsma <jaap@haitsma.org>
  * Copyright (C) 2008 Patryk Zawadzki <patrys@pld-linux.org>
  * Copyright (C) 2008 Ryan Zeigler <zeiglerr@gmail.com>
+ * Copyright (C) 2008 Filippo Argiolas <filippo.argiolas@gmail.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -60,9 +61,22 @@ typedef enum
   WEBCAM_MODE_VIDEO
 } WebcamMode;
 
+typedef enum
+{
+  CHEESE_RESPONSE_SKIP,
+  CHEESE_RESPONSE_SKIP_ALL,
+  CHEESE_RESPONSE_DELETE_ALL
+} CheeseDeleteResponseType;
+
+#define CHEESE_BUTTON_SKIP _("_Skip")
+#define CHEESE_BUTTON_SKIP_ALL _("S_kip All")
+#define CHEESE_BUTTON_DELETE_ALL _("Delete _All")
+
 typedef struct 
 {
   gboolean recording;
+  
+  gboolean isFullscreen;
 
   /* UDI device requested on the command line */
   char *startup_hal_dev_udi;
@@ -127,6 +141,7 @@ typedef struct
   GtkActionGroup *actions_photo;
   GtkActionGroup *actions_toggle;
   GtkActionGroup *actions_video;
+  GtkActionGroup *actions_fullscreen;
 
   GtkUIManager *ui_manager;
 
@@ -153,7 +168,7 @@ cheese_about_dialog_handle_url (GtkAboutDialog *dialog, const char *url, gpointe
                                            _("Failed to open browser to show:\n%s"), url); 
     gtk_dialog_run (GTK_DIALOG (error_dialog));
     gtk_widget_destroy (error_dialog);
-    g_error_free(error);
+    g_error_free (error);
   }
 }
 
@@ -177,7 +192,7 @@ cheese_about_dialog_handle_email (GtkAboutDialog *dialog, const char *email, gpo
                                            _("Failed to open email client to send message to:\n%s"), email); 
     gtk_dialog_run (GTK_DIALOG (error_dialog));
     gtk_widget_destroy (error_dialog);
-    g_error_free(error);
+    g_error_free (error);
   }
   g_free (uri);
 }
@@ -205,12 +220,39 @@ cheese_window_delete_event_cb (GtkWidget *widget, GdkEvent event, gpointer data)
 }
 
 static void
-cheese_window_photo_saved_cb (CheeseWebcam *webcam, CheeseWindow *cheese_window)
+cheese_window_make_fullscreen (GtkWidget *widget, CheeseWindow *cheese_window)
 {
+  GtkWidget *menubar;
+  menubar = gtk_ui_manager_get_widget (cheese_window->ui_manager, "/MainMenu");
+  
+  if (!cheese_window->isFullscreen)
+  {
+    gtk_widget_hide (cheese_window->thumb_view);
+    gtk_widget_hide (cheese_window->thumb_scrollwindow);
+    gtk_widget_hide (menubar);
+    
+    gtk_window_fullscreen (GTK_WINDOW (cheese_window->window));
+  }
+  else
+  {
+    gtk_widget_show_all (cheese_window->window);
+    gtk_window_unfullscreen ( GTK_WINDOW (cheese_window->window));
+  }
+  cheese_window->isFullscreen = !cheese_window->isFullscreen;
+}
+
+static void
+cheese_window_photo_saved_cb (CheeseWebcam *webcam, CheeseWindow *cheese_window)
+{  
   // TODO look at this g_free
   g_free (cheese_window->photo_filename);
   cheese_window->photo_filename = NULL;
   gtk_widget_set_sensitive (cheese_window->take_picture, TRUE);
+  
+  
+  //experimental fullscreen
+  //cheese_window->isFullscreen = !cheese_window->isFullscreen;
+  //cheese_window_make_fullscreen (cheese_window, cheese_window->isFullscreen);
 }
 
 static void
@@ -219,7 +261,7 @@ cheese_window_video_saved_cb (CheeseWebcam *webcam, CheeseWindow *cheese_window)
   // TODO look at this g_free
   g_free (cheese_window->video_filename);
   cheese_window->video_filename = NULL;
-  gtk_widget_set_sensitive (cheese_window->button_effects, TRUE);
+  gtk_action_group_set_sensitive (cheese_window->actions_effects, TRUE);
   gtk_widget_set_sensitive (cheese_window->take_picture, TRUE);
 }
 
@@ -244,6 +286,7 @@ cheese_window_cmd_close (GtkWidget *widget, CheeseWindow *cheese_window)
   g_object_unref (cheese_window->actions_preferences);
   g_object_unref (cheese_window->actions_file);
   g_object_unref (cheese_window->actions_video);
+  g_object_unref (cheese_window->actions_fullscreen);
   g_object_unref (cheese_window->ui_manager);
   g_object_unref (cheese_window->gconf);
 
@@ -274,7 +317,7 @@ cheese_window_cmd_open (GtkWidget *widget, CheeseWindow *cheese_window)
                                      _("Failed to launch program to show:\n%s"), uri);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
-    g_error_free(error);
+    g_error_free (error);
   }
   g_free (uri);
 }
@@ -339,44 +382,117 @@ cheese_window_cmd_save_as (GtkWidget *widget, CheeseWindow *cheese_window)
       gtk_widget_destroy (dlg);
       g_free (header);
     }
-    g_free(target_filename);
+    g_free (target_filename);
   }
-  g_free(filename);
+  g_free (filename);
   gtk_widget_destroy (dialog);
 }
 
+static void
+cheese_window_delete_error_dialog (CheeseWindow *cheese_window, GFile *file, gchar *message)
+{
+  gchar *primary, *secondary;
+  GtkWidget *error_dialog;
+  primary = g_strdup (_("Error while deleting"));
+  secondary = g_strdup_printf (_("The file \"%s\" cannot be deleted. Details: %s"),
+			       g_file_get_basename (file), message);
+  error_dialog = gtk_message_dialog_new (GTK_WINDOW (cheese_window->window),
+					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", primary);
+  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog),
+					    "%s", secondary);
+  gtk_dialog_run (GTK_DIALOG (error_dialog));
+  gtk_widget_destroy (error_dialog);
+  g_free (primary);
+  g_free (secondary);
+}
+
 static void
 cheese_window_cmd_move_file_to_trash (CheeseWindow *cheese_window, GList *files)
 {
-  GError *error;
+  GError *error = NULL;
   GList *l;
   gchar *primary, *secondary;
-  GtkWidget *error_dialog;
+  GtkWidget *question_dialog;
+  gint response;
+  gint list_length = g_list_length (files);
+  gboolean delete_all = FALSE;
+  
+  g_print ("received %d items to delete\n", list_length);
 
   for (l = files; l != NULL; l = l->next)
   {
-    if (!g_file_trash (l->data, NULL, &error))
+    /* don't enter the move to trash cycle if delete all is set */
+    if (delete_all) 
     {
-      primary = g_strdup (_("Cannot move file to trash"));
-      secondary = g_strdup_printf (_("The file \"%s\" cannot be moved to the trash. Details: %s"),
-                                   g_file_get_basename (l->data), error->message);
-
-      error_dialog = gtk_message_dialog_new (GTK_WINDOW (cheese_window->window),
-                                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                             GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", primary);
-      gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog),
-                                                "%s", secondary);
-      gtk_dialog_run (GTK_DIALOG (error_dialog));
-      gtk_widget_destroy (error_dialog);
-
-      g_free (primary);
-      g_free (secondary);
-      g_error_free(error);
-      /*TODO if we can't move files to trash, maybe we should try to delete them....*/
+      g_print ("deleting %s\n", g_file_get_basename (l->data));
+      if (!g_file_delete (l->data, NULL, &error))
+      {
+        cheese_window_delete_error_dialog (cheese_window, l->data, 
+                                           error != NULL ? error->message : _("Unknown Error"));
+        g_error_free (error);
+        error = NULL;
+      } 
     }
+    else
+    {
+      if (!g_file_trash (l->data, NULL, &error))
+      {
+	primary = g_strdup (_("Cannot move file to trash, do you want to delete immediately?"));
+	secondary = g_strdup_printf (_("The file \"%s\" cannot be moved to the trash. Details: %s"),
+				     g_file_get_basename (l->data), error->message);
+	question_dialog = gtk_message_dialog_new (GTK_WINDOW (cheese_window->window),
+						  GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", primary);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (question_dialog),
+						  "%s", secondary);
+	gtk_dialog_add_button (GTK_DIALOG (question_dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL); 
+	if (list_length > 1)
+	{
+	  /* no need for all those buttons we have a single file to delete */
+	  gtk_dialog_add_button (GTK_DIALOG (question_dialog), CHEESE_BUTTON_SKIP, CHEESE_RESPONSE_SKIP); 
+	  gtk_dialog_add_button (GTK_DIALOG (question_dialog), CHEESE_BUTTON_SKIP_ALL, CHEESE_RESPONSE_SKIP_ALL); 
+	  gtk_dialog_add_button (GTK_DIALOG (question_dialog), CHEESE_BUTTON_DELETE_ALL, CHEESE_RESPONSE_DELETE_ALL); 
+	}
+	gtk_dialog_add_button (GTK_DIALOG (question_dialog), GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT); 
+	response = gtk_dialog_run (GTK_DIALOG (question_dialog));
+	gtk_widget_destroy (question_dialog);
+	g_free (primary);
+	g_free (secondary);
+	g_error_free (error);
+	error = NULL;
+	switch (response) 
+	{
+	case CHEESE_RESPONSE_DELETE_ALL:
+	  /* don't break so we delete the current item too */
+	  delete_all = TRUE;
+	case GTK_RESPONSE_ACCEPT:
+	  g_print ("deleting %s\n", g_file_get_basename (l->data));
+	  if (!g_file_delete (l->data, NULL, &error))
+	  {
+	       cheese_window_delete_error_dialog (cheese_window, 
+						  l->data, 
+						  error != NULL ? error->message : _("Unknown Error"));
+	    g_error_free (error);
+	    error = NULL;
+	  }
+	  break;
+	case CHEESE_RESPONSE_SKIP:
+	  /* do nothing, skip to the next item */
+	  break;
+	case CHEESE_RESPONSE_SKIP_ALL:
+	case GTK_RESPONSE_CANCEL:
+	case GTK_RESPONSE_DELETE_EVENT:
+	default:
+	  /* cancel the whole delete operation */
+	  return;
+	}
+      }
+    }
+    g_object_unref (l->data);
   }
 }
-
+  
 static void
 cheese_window_move_all_media_to_trash (GtkWidget *widget, CheeseWindow *cheese_window)
 {
@@ -409,7 +525,7 @@ cheese_window_move_all_media_to_trash (GtkWidget *widget, CheeseWindow *cheese_w
   if (response !=  GTK_RESPONSE_OK)
     return;
 
-  //delete all videos
+  //append all videos
   path_videos = cheese_fileutil_get_video_path (cheese_window->fileutil);
   dir_videos = g_dir_open (path_videos, 0, NULL);
   while ((name = g_dir_read_name (dir_videos)) != NULL)
@@ -423,11 +539,8 @@ cheese_window_move_all_media_to_trash (GtkWidget *widget, CheeseWindow *cheese_w
       g_free (filename);
     }
   }
-  cheese_window_cmd_move_file_to_trash (cheese_window, files_list);
-  g_list_free (files_list);
   g_dir_close (dir_videos);
-  
-  //delete all photos
+  //append all photos
   path_photos = cheese_fileutil_get_photo_path (cheese_window->fileutil);
   dir_photos = g_dir_open (path_photos, 0, NULL);
   while ((name = g_dir_read_name (dir_photos)) != NULL)
@@ -441,6 +554,7 @@ cheese_window_move_all_media_to_trash (GtkWidget *widget, CheeseWindow *cheese_w
       g_free (filename);
     }
   }
+  //delete all items
   cheese_window_cmd_move_file_to_trash (cheese_window, files_list);
   g_list_free (files_list);
   g_dir_close (dir_photos);
@@ -480,7 +594,7 @@ cheese_window_cmd_set_about_me_photo (GtkWidget *widget, CheeseWindow *cheese_wi
 {
   EContact *contact;
   EBook *book;
-  GError *error;
+  GError *error = NULL;
   GdkPixbuf *pixbuf;
   const int MAX_PHOTO_HEIGHT = 150;
   const int MAX_PHOTO_WIDTH = 150;
@@ -491,7 +605,7 @@ cheese_window_cmd_set_about_me_photo (GtkWidget *widget, CheeseWindow *cheese_wi
   if (e_book_get_self (&contact, &book, NULL) && filename) 
   {
     char *name = e_contact_get (contact, E_CONTACT_FULL_NAME);
-    g_print("Setting Account Photo for %s\n", name);
+    g_print ("Setting Account Photo for %s\n", name);
 
     pixbuf = gdk_pixbuf_new_from_file_at_scale (filename, MAX_PHOTO_HEIGHT, 
                                                 MAX_PHOTO_WIDTH, TRUE, NULL);
@@ -510,7 +624,7 @@ cheese_window_cmd_set_about_me_photo (GtkWidget *widget, CheeseWindow *cheese_wi
                                  "compression", "9", NULL); 
       e_contact_set (contact, E_CONTACT_PHOTO, &photo);
 
-      if (!e_book_commit_contact(book, contact, &error)) 
+      if (!e_book_commit_contact (book, contact, &error)) 
       {
         char *header;
         GtkWidget *dlg;
@@ -714,7 +828,7 @@ cheese_window_effect_button_pressed_cb (GtkWidget *widget, CheeseWindow *cheese_
 {
   if (gtk_notebook_get_current_page (GTK_NOTEBOOK (cheese_window->notebook)) == 1)
   {
-    gtk_notebook_set_current_page (GTK_NOTEBOOK(cheese_window->notebook), 0);
+    gtk_notebook_set_current_page (GTK_NOTEBOOK (cheese_window->notebook), 0);
     gtk_label_set_text_with_mnemonic (GTK_LABEL (cheese_window->label_effects), _("_Effects"));
     gtk_widget_set_sensitive (cheese_window->take_picture, TRUE);
     if (cheese_window->webcam_mode == WEBCAM_MODE_PHOTO)
@@ -833,7 +947,7 @@ void
 cheese_window_countdown_hide_cb (gpointer data)
 {
   CheeseWindow *cheese_window = (CheeseWindow *) data;
-  gtk_notebook_set_current_page(GTK_NOTEBOOK(cheese_window->notebook_bar), 0);
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (cheese_window->notebook_bar), 0);
 }
 
 void
@@ -875,9 +989,9 @@ cheese_window_no_camera_message_area_response (GtkWidget *widget, gint response_
                                   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                   GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
                                   _("Unable to open help file for Cheese"));
-      gtk_dialog_run(GTK_DIALOG(d));
-      gtk_widget_destroy(d);
-      g_error_free(error);
+      gtk_dialog_run (GTK_DIALOG (d));
+      gtk_widget_destroy (d);
+      g_error_free (error);
     }
   }
 }
@@ -888,7 +1002,7 @@ cheese_window_stop_recording (CheeseWindow *cheese_window)
   if (cheese_window->recording)
   {
     cheese_webcam_stop_video_recording (cheese_window->webcam);
-    gtk_widget_set_sensitive (cheese_window->button_effects, TRUE);
+    gtk_action_group_set_sensitive (cheese_window->actions_effects, TRUE);
     gtk_widget_set_sensitive (cheese_window->button_photo, TRUE);
     gtk_widget_set_sensitive (cheese_window->button_video, TRUE);
     gchar * str = g_strconcat ("<b>", _("_Start Recording"), "</b>", NULL);
@@ -933,11 +1047,11 @@ cheese_window_action_button_clicked_cb (GtkWidget *widget, CheeseWindow *cheese_
     g_object_get (cheese_window->gconf, "gconf_prop_countdown", &countdown, NULL);
     if (countdown)
     {
-      cheese_countdown_start((CheeseCountdown *) cheese_window->countdown,
-                             cheese_window_countdown_picture_cb,
-                             cheese_window_countdown_hide_cb,
-                             (gpointer) cheese_window);
-      gtk_notebook_set_current_page (GTK_NOTEBOOK(cheese_window->notebook_bar), 1);
+      cheese_countdown_start ((CheeseCountdown *) cheese_window->countdown,
+                              cheese_window_countdown_picture_cb,
+                              cheese_window_countdown_hide_cb,
+                              (gpointer) cheese_window);
+      gtk_notebook_set_current_page (GTK_NOTEBOOK (cheese_window->notebook_bar), 1);
     }
     else
     {
@@ -951,7 +1065,7 @@ cheese_window_action_button_clicked_cb (GtkWidget *widget, CheeseWindow *cheese_
   {
     if (!cheese_window->recording)
     {
-      gtk_widget_set_sensitive (cheese_window->button_effects, FALSE);
+      gtk_action_group_set_sensitive (cheese_window->actions_effects, FALSE);
       gtk_widget_set_sensitive (cheese_window->button_photo, FALSE);
       gtk_widget_set_sensitive (cheese_window->button_video, FALSE);
       str = g_strconcat ("<b>", _("_Stop Recording"), "</b>", NULL);
@@ -1005,6 +1119,10 @@ static const GtkActionEntry action_entries_preferences[] = {
   {"Preferences", GTK_STOCK_PREFERENCES, N_("Preferences"), NULL, NULL, G_CALLBACK (cheese_window_preferences_cb)},
 };
 
+static const GtkToggleActionEntry action_entries_fullscreen[] = {
+  {"Fullscreen", GTK_STOCK_FULLSCREEN , NULL, "F11", NULL, G_CALLBACK (cheese_window_make_fullscreen), FALSE},
+};
+
 static const GtkRadioActionEntry action_entries_toggle[] = {
   {"Photo", NULL, N_("_Photo"), NULL, NULL, 0},
   {"Video", NULL, N_("_Video"), NULL, NULL, 1},
@@ -1120,7 +1238,7 @@ cheese_window_set_message_area (CheeseWindow *cheese_window,
     return;
 
   gtk_container_add (GTK_CONTAINER (cheese_window->message_area_frame), cheese_window->message_area);
-  gtk_widget_show (GTK_WIDGET(cheese_window->message_area));
+  gtk_widget_show (GTK_WIDGET (cheese_window->message_area));
 }
 
 static void
@@ -1131,7 +1249,7 @@ cheese_window_create_window (CheeseWindow *cheese_window)
   GtkBuilder* builder;
 
 #ifdef HILDON
-  HildonProgram *program = hildon_program_get_instance();
+  HildonProgram *program = hildon_program_get_instance ();
   GtkWidget *menu;
   GtkWidget *menuitem;
 #else
@@ -1174,20 +1292,20 @@ cheese_window_create_window (CheeseWindow *cheese_window)
   /* Reparent widgets in case we use hildon. This saves us maintaining two
      GtkBuilder ui files
   */
-  cheese_window->window = hildon_window_new();
-  cheese_window->main_hbox = gtk_hbox_new(FALSE, 0);
-  hildon_program_add_window (program, HILDON_WINDOW(cheese_window->window));
-  gtk_container_add (GTK_CONTAINER(cheese_window->window), cheese_window->main_hbox);  
-  gtk_widget_ref(cheese_window->thumb_scrollwindow);
-  gtk_widget_ref(cheese_window->video_vbox);
-  gtk_container_remove(GTK_CONTAINER(cheese_window->video_vbox), cheese_window->thumb_scrollwindow);
-  gtk_container_remove(GTK_CONTAINER(cheese_window->main_vbox),cheese_window->video_vbox);
-  gtk_box_pack_start (GTK_BOX(cheese_window->main_hbox), cheese_window->video_vbox, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX(cheese_window->main_hbox), GTK_WIDGET(cheese_window->thumb_scrollwindow), FALSE, FALSE, 0);
-  gtk_widget_destroy(cheese_window->main_vbox);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(cheese_window->thumb_scrollwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  gtk_widget_unref(cheese_window->thumb_scrollwindow);
-  gtk_widget_unref(cheese_window->video_vbox);
+  cheese_window->window = hildon_window_new ();
+  cheese_window->main_hbox = gtk_hbox_new (FALSE, 0);
+  hildon_program_add_window (program, HILDON_WINDOW (cheese_window->window));
+  gtk_container_add (GTK_CONTAINER (cheese_window->window), cheese_window->main_hbox);  
+  gtk_widget_ref (cheese_window->thumb_scrollwindow);
+  gtk_widget_ref (cheese_window->video_vbox);
+  gtk_container_remove (GTK_CONTAINER (cheese_window->video_vbox), cheese_window->thumb_scrollwindow);
+  gtk_container_remove (GTK_CONTAINER (cheese_window->main_vbox),cheese_window->video_vbox);
+  gtk_box_pack_start (GTK_BOX (cheese_window->main_hbox), cheese_window->video_vbox, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (cheese_window->main_hbox), GTK_WIDGET (cheese_window->thumb_scrollwindow), FALSE, FALSE, 0);
+  gtk_widget_destroy (cheese_window->main_vbox);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (cheese_window->thumb_scrollwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+  gtk_widget_unref (cheese_window->thumb_scrollwindow);
+  gtk_widget_unref (cheese_window->video_vbox);
 #endif
 
   g_object_unref (builder);
@@ -1240,6 +1358,10 @@ cheese_window_create_window (CheeseWindow *cheese_window)
                                                                           "ActionsEffects", 
                                                                           action_entries_effects, 
                                                                           G_N_ELEMENTS (action_entries_effects));
+  cheese_window->actions_fullscreen = cheese_window_toggle_action_group_new (cheese_window, 
+                                                                             "ActionsFullscreen", 
+                                                                             action_entries_fullscreen, 
+                                                                             G_N_ELEMENTS (action_entries_fullscreen));
   cheese_window->actions_preferences = cheese_window_action_group_new (cheese_window, 
                                                                        "ActionsPreferences", 
                                                                        action_entries_preferences, 
@@ -1324,20 +1446,20 @@ cheese_window_create_window (CheeseWindow *cheese_window)
   }
 
 #ifdef HILDON
-  menu = gtk_menu_new();
-  menuitem = gtk_menu_item_new_with_label(_("Quit"));
-  g_signal_connect(menuitem,"activate",
-                   GTK_SIGNAL_FUNC(cheese_window_cmd_close),
-                   cheese_window);
-  gtk_menu_append(menu, menuitem);
+  menu = gtk_menu_new ();
+  menuitem = gtk_menu_item_new_with_label (_("Quit"));
+  g_signal_connect (menuitem,"activate",
+                    GTK_SIGNAL_FUNC (cheese_window_cmd_close),
+                    cheese_window);
+  gtk_menu_append (menu, menuitem);
   
   menuitem = gtk_menu_item_new_with_label(_("About"));
-  g_signal_connect(menuitem,"activate",
-                   GTK_SIGNAL_FUNC(cheese_window_cmd_about), 
-                   cheese_window);
-  gtk_menu_append(menu, menuitem);
+  g_signal_connect (menuitem,"activate",
+                    GTK_SIGNAL_FUNC (cheese_window_cmd_about), 
+                    cheese_window);
+  gtk_menu_append (menu, menuitem);
   
-  hildon_window_set_menu (HILDON_WINDOW(cheese_window->window),GTK_MENU(menu));
+  hildon_window_set_menu (HILDON_WINDOW (cheese_window->window),GTK_MENU (menu));
 #else
   menubar = gtk_ui_manager_get_widget (cheese_window->ui_manager, "/MainMenu");
   gtk_box_pack_start (GTK_BOX (cheese_window->main_vbox), menubar, FALSE, FALSE, 0);
@@ -1355,16 +1477,17 @@ cheese_window_create_window (CheeseWindow *cheese_window)
 
   gtk_action_group_set_sensitive (cheese_window->actions_file, FALSE);
 
+  action = gtk_ui_manager_get_action (cheese_window->ui_manager, "/MainMenu/Edit/Effects");
+  gtk_action_connect_proxy (GTK_ACTION (action), GTK_WIDGET (cheese_window->button_effects));
+
   /* Default handlers for closing the application */
   g_signal_connect (cheese_window->window, "destroy",
                     G_CALLBACK (cheese_window_cmd_close), cheese_window);
   g_signal_connect (cheese_window->window, "delete_event", 
-                    G_CALLBACK(cheese_window_delete_event_cb), NULL);
+                    G_CALLBACK (cheese_window_delete_event_cb), NULL);
 
   g_signal_connect (cheese_window->take_picture, "clicked",
                     G_CALLBACK (cheese_window_action_button_clicked_cb), cheese_window);
-  g_signal_connect (cheese_window->button_effects,
-                    "clicked", G_CALLBACK (cheese_window_effect_button_pressed_cb), cheese_window);
   g_signal_connect (cheese_window->thumb_view, "button_press_event",
                     G_CALLBACK (cheese_window_button_press_event_cb), cheese_window);
 }
@@ -1403,14 +1526,14 @@ setup_camera (CheeseWindow *cheese_window)
                                      GTK_BUTTONS_OK, 
                                      "%s", error->message);
 
-    g_error_free(error);
+    g_error_free (error);
 
-    g_signal_connect(dialog, "response", G_CALLBACK(gtk_widget_destroy), NULL);
-    gtk_window_set_title(GTK_WINDOW (dialog), "Critical Error");
+    g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+    gtk_window_set_title (GTK_WINDOW (dialog), "Critical Error");
     gtk_dialog_run (GTK_DIALOG (dialog));
 
     // Clean up and exit
-    cheese_window_cmd_close(NULL, cheese_window);
+    cheese_window_cmd_close (NULL, cheese_window);
 
     gdk_threads_leave ();
   }
@@ -1425,11 +1548,11 @@ setup_camera (CheeseWindow *cheese_window)
 
   cheese_webcam_play (cheese_window->webcam);
   gdk_threads_enter ();
-  gtk_notebook_set_current_page (GTK_NOTEBOOK(cheese_window->notebook), 0);
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (cheese_window->notebook), 0);
   ephy_spinner_stop (EPHY_SPINNER (cheese_window->throbber));
   if (cheese_webcam_get_num_webcam_devices (cheese_window->webcam) == 0)
   {
-    message_area = cheese_no_camera_message_area();
+    message_area = cheese_no_camera_message_area ();
 
     g_signal_connect (message_area,
                       "response",
@@ -1454,13 +1577,14 @@ cheese_window_init (char *hal_dev_udi)
   cheese_window->audio_play_counter = 0;
   cheese_window->rand = g_rand_new ();
   cheese_window->fileutil = cheese_fileutil_new ();
+  cheese_window->isFullscreen = FALSE;
 
   cheese_window_create_window (cheese_window);
  
   gtk_widget_show_all (cheese_window->window);
   ephy_spinner_start (EPHY_SPINNER (cheese_window->throbber));
 
-  gtk_notebook_set_current_page (GTK_NOTEBOOK(cheese_window->notebook), 2);
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (cheese_window->notebook), 2);
 
   cheese_window->webcam_mode = WEBCAM_MODE_PHOTO;
   cheese_window->recording = FALSE;
